@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1685 2024/12/22 17:19:43 kirill Exp $
+# $OpenBSD: Quirks.pm,v 1.1693 2025/01/24 09:26:53 ajacoutot Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -603,6 +603,17 @@ my $stem_extensions = {
 	'cblas' => 'lapack',
 	'kio-extras' => 'kf6-kio-extras',
 	'py-rcsparse' => 'py3-rcsparse',
+	'py3-jsonschema-spec' => 'py3-jsonschema-path',
+	'kdepim-runtime-kf5' => 'kdepim-runtime',
+	'kcron-kf5' => 'kcron',
+	'dolphin-plugins-kf5' => 'dolphin-plugins',
+	'audiocd-kio-kf5' => 'audiocd-kio',
+	'py3-path.py' => 'py3-path',
+	'gstreamer1-plugins-bad' => 'gst-plugins-bad',
+	'gstreamer1-plugins-base' => 'gst-plugins-base',
+	'gstreamer1-plugins-good' => 'gst-plugins-good',
+	'gstreamer1-plugins-libav' => 'gst-libav',
+	'gstreamer1-plugins-ugly' => 'gst-plugins-ugly',
 };
 
 my $obsolete_reason = {};
@@ -1215,6 +1226,10 @@ setup_obsolete_reason(
 	3 => 'git-cvs',
 	7 => 'py3-uncompyle6',
 	6 => 'py-arsenic',
+	3 => 'py3-setuptools_scm_git_archive',
+	0 => 'burpsuite',
+	7 => 'govc',
+	7 => 'vcsim',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
